@@ -13,15 +13,12 @@ def main(target=""):
 
     package = importlib.import_module(__package__)
     modules = list(pkgutil.iter_modules(package.__path__))
-    choices = [m.name for m in modules]
+    choices = [m.name for m in modules if not m.name.startswith("_")]
 
-    cli = Bullet(prompt="\nSelect a script to run:", bullet=" ● ", choices=choices,)
+    cli = Bullet(prompt="\nSelect a script to run:", bullet=" ● ", choices=choices)
     if target not in choices:
         target = cli.launch()
+        print()
 
     module = importlib.import_module(f"{__package__}.{target}")
     module.main()
-
-
-if __name__ == "__main__":
-    main()
