@@ -1,12 +1,17 @@
+import os
+
 import pomace
 
 
+URL = "https://www.donaldjtrump.com/landing/the-official-2020-strategy-survey"
+
+
 def main():
     submits = 0
     errors = 0
 
     while errors < 10:
-        page = pomace.visit("https://www.donaldjtrump.com/landing/the-official-2020-strategy-survey")
+        page = pomace.visit(URL)
 
         page.click_stronger()
         page.click_reelected()
@@ -16,10 +21,11 @@ def main():
         page.click_twitter()
         page.click_vote()
 
-        page.fill_first_name("Jane")
-        page.fill_last_name("Doe")
-        page.fill_email("janedoe@example.com")
-        page.fill_zip(12345)
+        person = pomace.fake.person
+        page.fill_first_name(person.first_name)
+        page.fill_last_name(person.last_name)
+        page.fill_email(person.email)
+        page.fill_zip(person.zip)
 
         result = page.click_record_my_vote()
         if "has officially launched" in result:
@@ -28,3 +34,6 @@ def main():
             print(f"Submission count: {submits}")
         else:
             errors += 1
+
+        if submits >= 100 and "CI" in os.environ:
+            break
